@@ -7,6 +7,7 @@ use crate::serialize::per_type::{
     DateTimeError, DateTimeLike, DefaultSerializer, Offset, ZeroListSerializer,
 };
 use crate::serialize::serializer::PyObjectSerializer;
+use crate::str::PyStr;
 use crate::typeref::{load_numpy_types, ARRAY_STRUCT_STR, DESCR_STR, DTYPE_STR, NUMPY_TYPES};
 use crate::util::isize_to_usize;
 use core::ffi::{c_char, c_int, c_void};
@@ -17,7 +18,7 @@ use serde::ser::{self, Serialize, SerializeSeq, Serializer};
 use std::fmt;
 
 #[repr(transparent)]
-pub struct NumpySerializer<'a> {
+pub(crate) struct NumpySerializer<'a> {
     previous: &'a PyObjectSerializer,
 }
 
@@ -27,7 +28,7 @@ impl<'a> NumpySerializer<'a> {
     }
 }
 
-impl<'a> Serialize for NumpySerializer<'a> {
+impl Serialize for NumpySerializer<'_> {
     #[cold]
     #[inline(never)]
     #[cfg_attr(feature = "optimize", optimize(size))]
@@ -63,7 +64,7 @@ macro_rules! slice {
 }
 
 #[cold]
-pub fn is_numpy_scalar(ob_type: *mut PyTypeObject) -> bool {
+pub(crate) fn is_numpy_scalar(ob_type: *mut PyTypeObject) -> bool {
     let numpy_types = unsafe { NUMPY_TYPES.get_or_init(load_numpy_types) };
     if numpy_types.is_none() {
         false
@@ -86,7 +87,7 @@ pub fn is_numpy_scalar(ob_type: *mut PyTypeObject) -> bool {
 }
 
 #[cold]
-pub fn is_numpy_array(ob_type: *mut PyTypeObject) -> bool {
+pub(crate) fn is_numpy_array(ob_type: *mut PyTypeObject) -> bool {
     let numpy_types = unsafe { NUMPY_TYPES.get_or_init(load_numpy_types) };
     if numpy_types.is_none() {
         false
@@ -97,7 +98,7 @@ pub fn is_numpy_array(ob_type: *mut PyTypeObject) -> bool {
 }
 
 #[repr(C)]
-pub struct PyCapsule {
+pub(crate) struct PyCapsule {
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
     pub pointer: *mut c_void,
@@ -112,7 +113,7 @@ const NPY_ARRAY_C_CONTIGUOUS: c_int = 0x1;
 const NPY_ARRAY_NOTSWAPPED: c_int = 0x200;
 
 #[repr(C)]
-pub struct PyArrayInterface {
+pub(crate) struct PyArrayInterface {
     pub two: c_int,
     pub nd: c_int,
     pub typekind: c_char,
@@ -125,7 +126,7 @@ pub struct PyArrayInterface {
 }
 
 #[derive(Clone, Copy)]
-pub enum ItemType {
+pub(crate) enum ItemType {
     BOOL,
     DATETIME64(NumpyDatetimeUnit),
     F16,
@@ -165,7 +166,7 @@ impl ItemType {
     }
 }
 
-pub enum PyArrayError {
+pub(crate) enum PyArrayError {
     Malformed,
     NotContiguous,
     NotNativeEndian,
@@ -179,7 +180,7 @@ pub enum PyArrayError {
 // (2, 2, 2)
 // >>> arr.strides
 // (16, 8, 4)
-pub struct NumpyArray {
+pub(crate) struct NumpyArray {
     array: *mut PyArrayInterface,
     position: Vec<isize>,
     children: Vec<NumpyArray>,
@@ -402,7 +403,7 @@ impl<'a> NumpyF64Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyF64Array<'a> {
+impl Serialize for NumpyF64Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -418,7 +419,7 @@ impl<'a> Serialize for NumpyF64Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeF64 {
+pub(crate) struct DataTypeF64 {
     obj: f64,
 }
 
@@ -443,7 +444,7 @@ impl<'a> NumpyF32Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyF32Array<'a> {
+impl Serialize for NumpyF32Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -484,7 +485,7 @@ impl<'a> NumpyF16Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyF16Array<'a> {
+impl Serialize for NumpyF16Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -527,7 +528,7 @@ impl<'a> NumpyU64Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyU64Array<'a> {
+impl Serialize for NumpyU64Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -543,7 +544,7 @@ impl<'a> Serialize for NumpyU64Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeU64 {
+pub(crate) struct DataTypeU64 {
     obj: u64,
 }
 
@@ -568,7 +569,7 @@ impl<'a> NumpyU32Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyU32Array<'a> {
+impl Serialize for NumpyU32Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -584,7 +585,7 @@ impl<'a> Serialize for NumpyU32Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeU32 {
+pub(crate) struct DataTypeU32 {
     obj: u32,
 }
 
@@ -609,7 +610,7 @@ impl<'a> NumpyU16Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyU16Array<'a> {
+impl Serialize for NumpyU16Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -625,7 +626,7 @@ impl<'a> Serialize for NumpyU16Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeU16 {
+pub(crate) struct DataTypeU16 {
     obj: u16,
 }
 
@@ -650,7 +651,7 @@ impl<'a> NumpyI64Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyI64Array<'a> {
+impl Serialize for NumpyI64Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -666,7 +667,7 @@ impl<'a> Serialize for NumpyI64Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeI64 {
+pub(crate) struct DataTypeI64 {
     obj: i64,
 }
 
@@ -691,7 +692,7 @@ impl<'a> NumpyI32Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyI32Array<'a> {
+impl Serialize for NumpyI32Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -707,7 +708,7 @@ impl<'a> Serialize for NumpyI32Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeI32 {
+pub(crate) struct DataTypeI32 {
     obj: i32,
 }
 
@@ -732,7 +733,7 @@ impl<'a> NumpyI16Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyI16Array<'a> {
+impl Serialize for NumpyI16Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -748,7 +749,7 @@ impl<'a> Serialize for NumpyI16Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeI16 {
+pub(crate) struct DataTypeI16 {
     obj: i16,
 }
 
@@ -773,7 +774,7 @@ impl<'a> NumpyI8Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyI8Array<'a> {
+impl Serialize for NumpyI8Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -789,7 +790,7 @@ impl<'a> Serialize for NumpyI8Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeI8 {
+pub(crate) struct DataTypeI8 {
     obj: i8,
 }
 
@@ -814,7 +815,7 @@ impl<'a> NumpyU8Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyU8Array<'a> {
+impl Serialize for NumpyU8Array<'_> {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -830,7 +831,7 @@ impl<'a> Serialize for NumpyU8Array<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeU8 {
+pub(crate) struct DataTypeU8 {
     obj: u8,
 }
 
@@ -855,7 +856,7 @@ impl<'a> NumpyBoolArray<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyBoolArray<'a> {
+impl Serialize for NumpyBoolArray<'_> {
     #[cold]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
@@ -870,7 +871,7 @@ impl<'a> Serialize for NumpyBoolArray<'a> {
 }
 
 #[repr(transparent)]
-pub struct DataTypeBool {
+pub(crate) struct DataTypeBool {
     obj: u8,
 }
 
@@ -884,7 +885,7 @@ impl Serialize for DataTypeBool {
     }
 }
 
-pub struct NumpyScalar {
+pub(crate) struct NumpyScalar {
     ptr: *mut pyo3_ffi::PyObject,
     opts: Opt,
 }
@@ -946,7 +947,7 @@ impl Serialize for NumpyScalar {
 }
 
 #[repr(C)]
-pub struct NumpyInt8 {
+pub(crate) struct NumpyInt8 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: i8,
@@ -963,7 +964,7 @@ impl Serialize for NumpyInt8 {
 }
 
 #[repr(C)]
-pub struct NumpyInt16 {
+pub(crate) struct NumpyInt16 {
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
     pub value: i16,
@@ -980,7 +981,7 @@ impl Serialize for NumpyInt16 {
 }
 
 #[repr(C)]
-pub struct NumpyInt32 {
+pub(crate) struct NumpyInt32 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: i32,
@@ -997,7 +998,7 @@ impl Serialize for NumpyInt32 {
 }
 
 #[repr(C)]
-pub struct NumpyInt64 {
+pub(crate) struct NumpyInt64 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: i64,
@@ -1014,7 +1015,7 @@ impl Serialize for NumpyInt64 {
 }
 
 #[repr(C)]
-pub struct NumpyUint8 {
+pub(crate) struct NumpyUint8 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: u8,
@@ -1031,7 +1032,7 @@ impl Serialize for NumpyUint8 {
 }
 
 #[repr(C)]
-pub struct NumpyUint16 {
+pub(crate) struct NumpyUint16 {
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
     pub value: u16,
@@ -1048,7 +1049,7 @@ impl Serialize for NumpyUint16 {
 }
 
 #[repr(C)]
-pub struct NumpyUint32 {
+pub(crate) struct NumpyUint32 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: u32,
@@ -1065,7 +1066,7 @@ impl Serialize for NumpyUint32 {
 }
 
 #[repr(C)]
-pub struct NumpyUint64 {
+pub(crate) struct NumpyUint64 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: u64,
@@ -1082,7 +1083,7 @@ impl Serialize for NumpyUint64 {
 }
 
 #[repr(C)]
-pub struct NumpyFloat16 {
+pub(crate) struct NumpyFloat16 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: u16,
@@ -1100,7 +1101,7 @@ impl Serialize for NumpyFloat16 {
 }
 
 #[repr(C)]
-pub struct NumpyFloat32 {
+pub(crate) struct NumpyFloat32 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: f32,
@@ -1117,7 +1118,7 @@ impl Serialize for NumpyFloat32 {
 }
 
 #[repr(C)]
-pub struct NumpyFloat64 {
+pub(crate) struct NumpyFloat64 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: f64,
@@ -1134,7 +1135,7 @@ impl Serialize for NumpyFloat64 {
 }
 
 #[repr(C)]
-pub struct NumpyBool {
+pub(crate) struct NumpyBool {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: bool,
@@ -1155,7 +1156,7 @@ impl Serialize for NumpyBool {
 /// See
 /// https://github.com/numpy/numpy/blob/fc8e3bbe419748ac5c6b7f3d0845e4bafa74644b/numpy/core/include/numpy/ndarraytypes.h#L268-L282.
 #[derive(Clone, Copy)]
-pub enum NumpyDatetimeUnit {
+pub(crate) enum NumpyDatetimeUnit {
     NaT,
     Years,
     Months,
@@ -1246,7 +1247,7 @@ impl NumpyDatetimeUnit {
         let descr = ffi!(PyObject_GetAttr(dtype, DESCR_STR));
         let el0 = ffi!(PyList_GET_ITEM(descr, 0));
         let descr_str = ffi!(PyTuple_GET_ITEM(el0, 1));
-        let uni = crate::str::unicode_to_str(descr_str).unwrap();
+        let uni = unsafe { PyStr::from_ptr_unchecked(descr_str).to_str().unwrap() };
         if uni.len() < 5 {
             return Self::NaT;
         }
@@ -1337,7 +1338,7 @@ impl<'a> NumpyDatetime64Array<'a> {
     }
 }
 
-impl<'a> Serialize for NumpyDatetime64Array<'a> {
+impl Serialize for NumpyDatetime64Array<'_> {
     #[cold]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
@@ -1356,7 +1357,7 @@ impl<'a> Serialize for NumpyDatetime64Array<'a> {
 }
 
 #[repr(C)]
-pub struct NumpyDatetime64 {
+pub(crate) struct NumpyDatetime64 {
     ob_refcnt: Py_ssize_t,
     ob_type: *mut PyTypeObject,
     value: i64,
